Changelog
=========

v0.4.0
------
* sphinx documentation
* `plot_principal_plt` -> `plot_principal_planes`

v0.3.0
------
* renamed `pitch()` to `period()` to avoid stepping on the name.
* improve readme
* fix `pylint` warnings
* fix `pep257` warnings
* fix `pyroma` warnings

v0.2.0
------
* improve description
* add `hyperbolic_secant_profile_index`
* fix importing, update for new names

v0.2.0
------
* fix typos
* change status to alpha
